==> xaspy-0.1.3.tar.gz: xaspy-0.1.3/setup.py <==

from distutils.core import setup
setup(
  name = 'xaspy',         # How you named your package folder (MyLib)
  packages = ['xaspy',
              'xaspy.utils',
              'xaspy.xas',
              'xaspy.readin'],   # Chose the same as "name"
  version = '0.1.3',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'package for analysis of experimental xray absorption spectroscopy data',   # Give a short description about your library
  author = 'YOUR NAME',                   # Type in your name
  author_email = 'damian@guenzing.de',      # Type in your E-Mail
  url = 'https://github.com/gnzng/xaspy',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/gnzng/xaspy/archive/v_0_1_3.tar.gz',    # I explain this later on
  keywords = ['xray absorption spectroscopy', 'xmcd', 'synchrotron'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'validators',
          'beautifulsoup4',
          'numpy',
          'pandas',
          'scipy',
          'matplotlib'
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3.7',
  ],
)

==> xaspy-0.1.4.tar.gz: xaspy-0.1.4/setup.py <==

from distutils.core import setup
setup(
  name = 'xaspy',         # How you named your package folder (MyLib)
  packages = ['xaspy',
              'xaspy.utils',
              'xaspy.xas',
              'xaspy.readin',
              'xaspy.despike'],   # Chose the same as "name"
  version = '0.1.4',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'package for analysis of experimental xray absorption spectroscopy data',   # Give a short description about your library
  author = 'YOUR NAME',                   # Type in your name
  author_email = 'damian@guenzing.de',      # Type in your E-Mail
  url = 'https://github.com/gnzng/xaspy',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/gnzng/xaspy/archive/v_0_1_4.tar.gz',    # I explain this later on
  keywords = ['xray absorption spectroscopy', 'xmcd', 'synchrotron'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'validators',
          'beautifulsoup4',
          'numpy',
          'pandas',
          'scipy',
          'matplotlib'
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3.7',
  ],
)
